netapp_ontap.models.nvme_interface_fc_interface API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_interface_fc_interface`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeInterfaceFcInterfaceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeInterfaceFcInterface object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the nvme_interface_fc_interface.

  `port GET POST PATCH`

    The port field of the nvme_interface_fc_interface.

  `wwnn GET`

    The WWNN (world wide node name) of the Fibre Channel NVMe interface.

    Example: 20:00:00:50:56:b4:13:a9

  `wwpn GET`

    The WWPN (world wide port name) of the Fibre Channel NVMe interface.

    Example: 20:00:00:50:56:b4:13:a8